==> plantuml-libs-6.3.0.tgz: package/distribution/material-4/Notification/AirlineSeatFlatAngled.md <==
# AirlineSeatFlatAngled


```text
material-4/Notification/AirlineSeatFlatAngled
```

```text
include('material-4/Notification/AirlineSeatFlatAngled')
```



| Illustration | AirlineSeatFlatAngled |
| :---: | :---: |
| ![illustration for Illustration](../../material-4/Notification/AirlineSeatFlatAngled.png) | ![illustration for AirlineSeatFlatAngled](../../material-4/Notification/AirlineSeatFlatAngled.Local.png) |




## AirlineSeatFlatAngled

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('material-4/bootstrap')

' loads the Item which embeds the element AirlineSeatFlatAngled
include('material-4/Notification/AirlineSeatFlatAngled')

' renders the element
AirlineSeatFlatAngled('AirlineSeatFlatAngled', 'Airline Seat Flat Angled', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('material-4/bootstrap')

' loads the Item which embeds the element AirlineSeatFlatAngled
include('material-4/Notification/AirlineSeatFlatAngled')

' renders the element
AirlineSeatFlatAngled('AirlineSeatFlatAngled', 'Airline Seat Flat Angled', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/material-4/Notification/AirlineSeatFlatAngled.md <==
# AirlineSeatFlatAngled


```text
material-4/Notification/AirlineSeatFlatAngled
```

```text
include('material-4/Notification/AirlineSeatFlatAngled')
```



| Illustration | AirlineSeatFlatAngled |
| :---: | :---: |
| ![illustration for Illustration](../../material-4/Notification/AirlineSeatFlatAngled.png) | ![illustration for AirlineSeatFlatAngled](../../material-4/Notification/AirlineSeatFlatAngled.Local.png) |




## AirlineSeatFlatAngled

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('material-4/bootstrap')

' loads the Item which embeds the element AirlineSeatFlatAngled
include('material-4/Notification/AirlineSeatFlatAngled')

' renders the element
AirlineSeatFlatAngled('AirlineSeatFlatAngled', 'Airline Seat Flat Angled', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('material-4/bootstrap')

' loads the Item which embeds the element AirlineSeatFlatAngled
include('material-4/Notification/AirlineSeatFlatAngled')

' renders the element
AirlineSeatFlatAngled('AirlineSeatFlatAngled', 'Airline Seat Flat Angled', 'an optional tech label', 'an optional description')
@enduml
```
